==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/databox/kotlin/inputs/ImportDiskDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databox.kotlin.inputs

import com.pulumi.azurenative.databox.inputs.ImportDiskDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Import disk details
 * @property bitLockerKey BitLocker key used to encrypt the disk.
 * @property manifestFile The relative path of the manifest file on the disk.
 * @property manifestHash The Base16-encoded MD5 hash of the manifest file on the disk.
 */
public data class ImportDiskDetailsArgs(
    public val bitLockerKey: Output<String>,
    public val manifestFile: Output<String>,
    public val manifestHash: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.databox.inputs.ImportDiskDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.databox.inputs.ImportDiskDetailsArgs =
        com.pulumi.azurenative.databox.inputs.ImportDiskDetailsArgs.builder()
            .bitLockerKey(bitLockerKey.applyValue({ args0 -> args0 }))
            .manifestFile(manifestFile.applyValue({ args0 -> args0 }))
            .manifestHash(manifestHash.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ImportDiskDetailsArgs].
 */
@PulumiTagMarker
public class ImportDiskDetailsArgsBuilder internal constructor() {
    private var bitLockerKey: Output<String>? = null

    private var manifestFile: Output<String>? = null

    private var manifestHash: Output<String>? = null

    /**
     * @param value BitLocker key used to encrypt the disk.
     */
    @JvmName("bqmvslnbgljdtxeu")
    public suspend fun bitLockerKey(`value`: Output<String>) {
        this.bitLockerKey = value
    }

    /**
     * @param value The relative path of the manifest file on the disk.
     */
    @JvmName("hmxvhyntbpfaplcv")
    public suspend fun manifestFile(`value`: Output<String>) {
        this.manifestFile = value
    }

    /**
     * @param value The Base16-encoded MD5 hash of the manifest file on the disk.
     */
    @JvmName("lyfhilboqkesskbu")
    public suspend fun manifestHash(`value`: Output<String>) {
        this.manifestHash = value
    }

    /**
     * @param value BitLocker key used to encrypt the disk.
     */
    @JvmName("axvsjfdtewlovhij")
    public suspend fun bitLockerKey(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.bitLockerKey = mapped
    }

    /**
     * @param value The relative path of the manifest file on the disk.
     */
    @JvmName("osqlvvnimnomluyh")
    public suspend fun manifestFile(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.manifestFile = mapped
    }

    /**
     * @param value The Base16-encoded MD5 hash of the manifest file on the disk.
     */
    @JvmName("eghnftiupinegedb")
    public suspend fun manifestHash(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.manifestHash = mapped
    }

    internal fun build(): ImportDiskDetailsArgs = ImportDiskDetailsArgs(
        bitLockerKey = bitLockerKey ?: throw PulumiNullFieldException("bitLockerKey"),
        manifestFile = manifestFile ?: throw PulumiNullFieldException("manifestFile"),
        manifestHash = manifestHash ?: throw PulumiNullFieldException("manifestHash"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/databox/kotlin/inputs/ImportDiskDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databox.kotlin.inputs

import com.pulumi.azurenative.databox.inputs.ImportDiskDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Import disk details
 * @property bitLockerKey BitLocker key used to encrypt the disk.
 * @property manifestFile The relative path of the manifest file on the disk.
 * @property manifestHash The Base16-encoded MD5 hash of the manifest file on the disk.
 */
public data class ImportDiskDetailsArgs(
    public val bitLockerKey: Output<String>,
    public val manifestFile: Output<String>,
    public val manifestHash: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.databox.inputs.ImportDiskDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.databox.inputs.ImportDiskDetailsArgs =
        com.pulumi.azurenative.databox.inputs.ImportDiskDetailsArgs.builder()
            .bitLockerKey(bitLockerKey.applyValue({ args0 -> args0 }))
            .manifestFile(manifestFile.applyValue({ args0 -> args0 }))
            .manifestHash(manifestHash.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ImportDiskDetailsArgs].
 */
@PulumiTagMarker
public class ImportDiskDetailsArgsBuilder internal constructor() {
    private var bitLockerKey: Output<String>? = null

    private var manifestFile: Output<String>? = null

    private var manifestHash: Output<String>? = null

    /**
     * @param value BitLocker key used to encrypt the disk.
     */
    @JvmName("isjaonmoaifmisth")
    public suspend fun bitLockerKey(`value`: Output<String>) {
        this.bitLockerKey = value
    }

    /**
     * @param value The relative path of the manifest file on the disk.
     */
    @JvmName("ukurkhjaxlhjrcwv")
    public suspend fun manifestFile(`value`: Output<String>) {
        this.manifestFile = value
    }

    /**
     * @param value The Base16-encoded MD5 hash of the manifest file on the disk.
     */
    @JvmName("ermjfseeknhibpgc")
    public suspend fun manifestHash(`value`: Output<String>) {
        this.manifestHash = value
    }

    /**
     * @param value BitLocker key used to encrypt the disk.
     */
    @JvmName("qqoupcljlyguwhxk")
    public suspend fun bitLockerKey(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.bitLockerKey = mapped
    }

    /**
     * @param value The relative path of the manifest file on the disk.
     */
    @JvmName("jordfwmlfuoqwwsc")
    public suspend fun manifestFile(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.manifestFile = mapped
    }

    /**
     * @param value The Base16-encoded MD5 hash of the manifest file on the disk.
     */
    @JvmName("jplhqlffxdqclksq")
    public suspend fun manifestHash(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.manifestHash = mapped
    }

    internal fun build(): ImportDiskDetailsArgs = ImportDiskDetailsArgs(
        bitLockerKey = bitLockerKey ?: throw PulumiNullFieldException("bitLockerKey"),
        manifestFile = manifestFile ?: throw PulumiNullFieldException("manifestFile"),
        manifestHash = manifestHash ?: throw PulumiNullFieldException("manifestHash"),
    )
}
